@@ -106,9 +106,13 @@ leaflet() %>%
 ## -----------------------------------------------------------------------------
 r = response_map
 
-## -----------------------------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
+#  library(stars)
+#  plot(r)
+
+## ---- echo=FALSE--------------------------------------------------------------
 library(stars)
-plot(r)
+plot(r, useRaster = TRUE)
 
 ## -----------------------------------------------------------------------------
 library(ggplot2)
